@@ -61,18 +61,18 @@ summary.svyglm<-function (object, correlation = FALSE, df.resid=NULL,...)
     else
       df.r<-df.resid
     
-    dispersion<-survey::svyvar(resid(object,"pearson"), object$survey.design,
+    dispersion<-survey::svyvar(stats::resid(object,"pearson"), object$survey.design,
                        na.rm=TRUE)
     
-    coef.p <- coef(object)
-    covmat<-vcov(object)
+    coef.p <- stats::coef(object)
+    covmat<-stats::vcov(object)
     dimnames(covmat) <- list(names(coef.p), names(coef.p))
     var.cf <- diag(covmat)
     s.err <- sqrt(var.cf)
     tvalue <- coef.p/s.err
     if(object$family$family == "binomial"){
      dn <- c("Estimate", "Lower")
-     qvalue <- qt(0.975,df=df.r)
+     qvalue <- stats::qt(0.975,df=df.r)
      if (!est.disp) {
         pvalue <- 2 * pnorm(-abs(tvalue))
         coef.table <- cbind(exp(coef.p), 
@@ -82,7 +82,7 @@ summary.svyglm<-function (object, correlation = FALSE, df.resid=NULL,...)
                                          c(dn, "Upper","Pr(>|z|)"))
      }
      else if (df.r > 0) {
-        pvalue <- 2 * pt(-abs(tvalue), df.r)
+        pvalue <- 2 * stats::pt(-abs(tvalue), df.r)
         coef.table <- cbind(exp(coef.p), 
               exp(coef.p-qvalue*s.err), 
 	      exp(coef.p+qvalue*s.err), pvalue)
@@ -102,7 +102,7 @@ summary.svyglm<-function (object, correlation = FALSE, df.resid=NULL,...)
             "Pr(>|z|)"))
      }
      else if (df.r > 0) {
-        pvalue <- 2 * pt(-abs(tvalue), df.r)
+        pvalue <- 2 * stats::pt(-abs(tvalue), df.r)
         coef.table <- cbind(coef.p, s.err, tvalue, pvalue)
         dimnames(coef.table) <- list(names(coef.p), c(dn, "t value", 
             "Pr(>|t|)"))
@@ -114,7 +114,7 @@ summary.svyglm<-function (object, correlation = FALSE, df.resid=NULL,...)
     }
     ans <- c(object[c("call", "terms", "family", "deviance", 
         "aic", "contrasts", "df.residual", "null.deviance", "df.null", 
-        "iter")], list(deviance.resid = residuals(object, type = "deviance"), 
+        "iter")], list(deviance.resid = stats::residuals(object, type = "deviance"), 
         aic = object$aic, coefficients = coef.table, dispersion = dispersion, 
         df = c(object$rank, df.r,NCOL(Qr$qr)), cov.unscaled = covmat, 
         cov.scaled = covmat))
@@ -122,7 +122,7 @@ summary.svyglm<-function (object, correlation = FALSE, df.resid=NULL,...)
         dd <- sqrt(diag(covmat))
         ans$correlation <- covmat/outer(dd, dd)
     }
-    ans$aliased<-is.na(coef(object,na.rm=FALSE))
+    ans$aliased<-is.na(stats::coef(object,na.rm=FALSE))
     ans$survey.design<-list(call=object$survey.design$call)
     class(ans) <- c("summary.svyglm.RDS","summary.svyglm","summary.glm")
     return(ans)
@@ -160,7 +160,7 @@ print.summary.svyglm.RDS<-function (x, digits = max(3, getOption("digits") - 3),
                                 symbolic.cor = x$symbolic.cor, 
     signif.stars = getOption("show.signif.stars"), ...) 
 {
-  ##if (!exists("printCoefmat")) printCoefmat<-print.coefmat
+  ##if (!exists("printCoefmat")) stats::printCoefmat<-print.coefmat
 
   cat("\nCall:\n")
     cat(paste(deparse(x$call), sep = "\n", collapse = "\n"), 
@@ -194,7 +194,7 @@ print.summary.svyglm.RDS<-function (x, digits = max(3, getOption("digits") - 3),
         if(x$family$family == "binomial"){
 	  coefs[,1:3] <- exp(coefs[,1:3])
 	}
-        printCoefmat(coefs, digits = digits, signif.stars = signif.stars, 
+	stats::printCoefmat(coefs, digits = digits, signif.stars = signif.stars, 
             na.print = "NA", ...)
     
     cat("\n(Dispersion parameter for ", x$family$family, " family taken to be ", 
@@ -206,7 +206,7 @@ print.summary.svyglm.RDS<-function (x, digits = max(3, getOption("digits") - 3),
         if (p > 1) {
             cat("\nCorrelation of Coefficients:\n")
             if (is.logical(symbolic.cor) && symbolic.cor) {
-                print(symnum(correl, abbr.colnames = NULL))
+                print(stats::symnum(correl, abbr.colnames = NULL))
             }
             else {
                 correl <- format(round(correl, 2), nsmall = 2, 
